==> physx-jni-0.4.1-sources.jar: physx/vehicle/PxVehicleAckermannGeometryData.java <==
package physx.vehicle;

import physx.NativeObject;

public class PxVehicleAckermannGeometryData extends NativeObject {

    public static PxVehicleAckermannGeometryData wrapPointer(long address) {
        return address != 0L ? new PxVehicleAckermannGeometryData(address) : null;
    }
    
    protected PxVehicleAckermannGeometryData(long address) {
        super(address);
    }

    // Constructors

    public PxVehicleAckermannGeometryData() {
        address = _PxVehicleAckermannGeometryData();
    }
    private static native long _PxVehicleAckermannGeometryData();

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: float
     */
    public float getMAccuracy() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMAccuracy(address);
    }
    private static native float _getMAccuracy(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMAccuracy(float value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMAccuracy(address, value);
    }
    private static native void _setMAccuracy(long address, float value);

    /**
     * @return WebIDL type: float
     */
    public float getMFrontWidth() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMFrontWidth(address);
    }
    private static native float _getMFrontWidth(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMFrontWidth(float value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMFrontWidth(address, value);
    }
    private static native void _setMFrontWidth(long address, float value);

    /**
     * @return WebIDL type: float
     */
    public float getMRearWidth() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMRearWidth(address);
    }
    private static native float _getMRearWidth(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMRearWidth(float value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMRearWidth(address, value);
    }
    private static native void _setMRearWidth(long address, float value);

    /**
     * @return WebIDL type: float
     */
    public float getMAxleSeparation() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMAxleSeparation(address);
    }
    private static native float _getMAxleSeparation(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMAxleSeparation(float value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMAxleSeparation(address, value);
    }
    private static native void _setMAxleSeparation(long address, float value);

}

==> physx-jni-0.4.6-sources.jar: physx/vehicle/PxVehicleAckermannGeometryData.java <==
package physx.vehicle;

import physx.NativeObject;

public class PxVehicleAckermannGeometryData extends NativeObject {

    public static PxVehicleAckermannGeometryData wrapPointer(long address) {
        return address != 0L ? new PxVehicleAckermannGeometryData(address) : null;
    }
    
    protected PxVehicleAckermannGeometryData(long address) {
        super(address);
    }

    // Constructors

    public PxVehicleAckermannGeometryData() {
        address = _PxVehicleAckermannGeometryData();
    }
    private static native long _PxVehicleAckermannGeometryData();

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: float
     */
    public float getMAccuracy() {
        checkNotNull();
        return _getMAccuracy(address);
    }
    private static native float _getMAccuracy(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMAccuracy(float value) {
        checkNotNull();
        _setMAccuracy(address, value);
    }
    private static native void _setMAccuracy(long address, float value);

    /**
     * @return WebIDL type: float
     */
    public float getMFrontWidth() {
        checkNotNull();
        return _getMFrontWidth(address);
    }
    private static native float _getMFrontWidth(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMFrontWidth(float value) {
        checkNotNull();
        _setMFrontWidth(address, value);
    }
    private static native void _setMFrontWidth(long address, float value);

    /**
     * @return WebIDL type: float
     */
    public float getMRearWidth() {
        checkNotNull();
        return _getMRearWidth(address);
    }
    private static native float _getMRearWidth(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMRearWidth(float value) {
        checkNotNull();
        _setMRearWidth(address, value);
    }
    private static native void _setMRearWidth(long address, float value);

    /**
     * @return WebIDL type: float
     */
    public float getMAxleSeparation() {
        checkNotNull();
        return _getMAxleSeparation(address);
    }
    private static native float _getMAxleSeparation(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMAxleSeparation(float value) {
        checkNotNull();
        _setMAxleSeparation(address, value);
    }
    private static native void _setMAxleSeparation(long address, float value);

}
